Simple tests
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/lsm303dlh_mag_simpletest.py
    :caption: examples/lsm303dlh_mag_simpletest.py
    :linenos:

Fast Data Reading Example
-------------------------

Fast readings example

.. literalinclude:: ../examples/lsm303dlh_mag_fast.py
    :caption: examples/lsm303dlh_mag_fast.py
    :linenos:

Compass Example
---------------

Magnetic compass example

.. literalinclude:: ../examples/lsm303dlh_mag_compass.py
    :caption: examples/lsm303dlh_mag_compass.py
    :linenos:
